@@ -17,9 +17,11 @@
 #' apparent(mtcars)
 #' @export
 apparent <- function(data, ...) {
-  splits <- rsplit(data, in_id = 1:nrow(data), out_id = 1:nrow(data))
-  # splits <- rm_out(splits)
-  class(splits) <- c("rsplit", "apparent_split")
+  check_dots_empty()
+
+  splits <- rsplit(data, in_id = seq_len(nrow(data)), out_id = seq_len(nrow(data)))
+
+  class(splits) <- c("apparent_split", "rsplit")
   split_objs <- tibble::tibble(splits = list(splits), id = "Apparent")
 
   new_rset(
