@@ -17,7 +17,7 @@
 #' @param times The number of bootstrap samples.
 #' @param apparent A logical. Should an extra resample be added where the
 #'  analysis and holdout subset are the entire data set. This is required for
-#'  some estimators used by the `summary` function that require the apparent
+#'  some estimators used by the [summary()] function that require the apparent
 #'  error rate.
 #' @export
 #' @return A tibble with classes `bootstraps`, `rset`, `tbl_df`, `tbl`, and
@@ -69,12 +69,14 @@ bootstraps <-
            pool = 0.1,
            apparent = FALSE,
            ...) {
+    check_dots_empty()
+
     if (!missing(strata)) {
       strata <- tidyselect::vars_select(names(data), !!enquo(strata))
       if (length(strata) == 0) strata <- NULL
     }
 
-    strata_check(strata, data)
+    check_strata(strata, data)
 
     split_objs <-
       boot_splits(
@@ -84,6 +86,7 @@ bootstraps <-
         breaks = breaks,
         pool = pool
       )
+
     if (apparent) {
       split_objs <- bind_rows(split_objs, apparent(data))
     }
@@ -130,13 +133,14 @@ boot_splits <-
       )
       stratas <- split_unnamed(stratas, stratas$strata)
       stratas <-
-        purrr::map_df(
+        purrr::map(
           stratas,
           strat_sample,
           prop = 1,
           times = times,
           replace = TRUE
-        )
+        ) %>%
+        list_rbind()
       indices <- split_unnamed(stratas$idx, stratas$rs_id)
     }
 
@@ -144,6 +148,15 @@ boot_splits <-
 
     split_objs <-
       purrr::map(indices, make_splits, data = data, class = "boot_split")
+
+    all_assessable <- purrr::map(split_objs, function(x) nrow(assessment(x)))
+    if (any(all_assessable == 0)) {
+      cli_warn(
+        "Some assessment sets contained zero rows.",
+        call = rlang::caller_env()
+      )
+    }
+
     list(
       splits = split_objs,
       id = names0(length(split_objs), "Bootstrap")
@@ -186,17 +199,24 @@ group_bootstraps <- function(data,
                              group,
                              times = 25,
                              apparent = FALSE,
-                             ...) {
-
-  rlang::check_dots_empty()
+                             ...,
+                             strata = NULL,
+                             pool = 0.1) {
+  check_dots_empty()
 
   group <- validate_group({{ group }}, data)
 
+  if (!missing(strata)) {
+    strata <- check_grouped_strata({{ group }}, {{ strata }}, pool, data)
+  }
+
   split_objs <-
     group_boot_splits(
       data = data,
       group = group,
-      times = times
+      times = times,
+      strata = strata,
+      pool = pool
     )
 
   ## We remove the holdout indices since it will save space and we can
@@ -207,10 +227,13 @@ group_bootstraps <- function(data,
     split_objs <- bind_rows(split_objs, apparent(data))
   }
 
+  # This is needed for printing checks; strata can't be missing
+  if (is.null(strata)) strata <- FALSE
   boot_att <- list(
     times = times,
     apparent = apparent,
-    strata = FALSE,
+    strata = strata,
+    pool = pool,
     group = group
   )
 
@@ -222,21 +245,41 @@ group_bootstraps <- function(data,
   )
 }
 
-group_boot_splits <- function(data, group, times = 25) {
+group_boot_splits <- function(data, group, times = 25, strata = NULL, pool = 0.1) {
 
   group <- getElement(data, group)
-  n <- nrow(data)
-  indices <- make_groups(data, group, times, balance = "prop", prop = 1, replace = TRUE)
-  indices <- lapply(indices, boot_complement, n = n)
-  split_objs <-
-    purrr::map(indices, make_splits, data = data, class = c("group_boot_split", "boot_split"))
-  all_assessable <- purrr::map(split_objs, function(x) nrow(assessment(x)))
+  if (!is.null(strata)) {
+    strata <- getElement(data, strata)
+    strata <- as.character(strata)
+    strata <- make_strata(strata, pool = pool)
+  }
 
+  n <- nrow(data)
+
+  indices <- make_groups(
+    data,
+    group,
+    times,
+    balance = "prop",
+    prop = 1,
+    replace = TRUE,
+    strata = strata
+  )
+
+  indices <- lapply(indices, boot_complement, n = n)
+  split_objs <- purrr::map(
+    indices,
+    make_splits,
+    data = data,
+    class = c("group_boot_split", "boot_split")
+  )
+
+  all_assessable <- purrr::map(split_objs, function(x) nrow(assessment(x)))
   if (any(all_assessable == 0)) {
-    rlang::abort(
+    cli_warn(
       c(
-        "Some assessment sets contained zero rows",
-        i = "Consider using a non-grouped resampling method"
+        "Some assessment sets contained zero rows.",
+        i = "Consider using a non-grouped resampling method."
       ),
       call = rlang::caller_env()
     )
