@@ -4,15 +4,16 @@
 #'  \pkg{rsample} and \pkg{caret}.
 #'
 #' @param object An `rset` object. Currently,
-#'  `nested_cv` is not supported.
-#' @return `rsample2caret` returns a list that mimics the
+#'  [nested_cv()] is not supported.
+#' @return `rsample2caret()` returns a list that mimics the
 #'  `index` and `indexOut` elements of a
-#'  `trainControl` object. `caret2rsample` returns an
+#'  `trainControl` object. `caret2rsample()` returns an
 #'  `rset` object of the appropriate class.
 #' @export
 rsample2caret <- function(object, data = c("analysis", "assessment")) {
-  if(!inherits(object, "rset"))
-    stop("`object` must be an `rset`", call. = FALSE)
+  if (!inherits(object, "rset")) {
+    cli_abort("{.arg object} must be an {.cls rset}.")
+  }
   data <- rlang::arg_match(data)
   in_ind <- purrr::map(object$splits, as.integer, data = "analysis")
   names(in_ind) <- labels(object)
@@ -22,7 +23,7 @@ rsample2caret <- function(object, data = c("analysis", "assessment")) {
 }
 
 #' @rdname rsample2caret
-#' @param ctrl An object produced by `trainControl` that has
+#' @param ctrl An object produced by `caret::trainControl()` that has
 #'  had the `index` and `indexOut` elements populated by
 #'  integers. One method of getting this is to extract the
 #'  `control` objects from an object produced by `train`.
@@ -30,16 +31,21 @@ rsample2caret <- function(object, data = c("analysis", "assessment")) {
 #'  `ctrl` object.
 #' @export
 caret2rsample <- function(ctrl, data = NULL) {
-  if (is.null(data))
-    stop("Must supply original data", call. = FALSE)
-  if (!any(names(ctrl) == "index"))
-    stop("`ctrl` should have an element `index`", call. = FALSE)
-  if (!any(names(ctrl) == "indexOut"))
-    stop("`ctrl` should have an element `indexOut`", call. = FALSE)
-  if (is.null(ctrl$index))
-    stop("`ctrl$index` should be populated with integers", call. = FALSE)
-  if (is.null(ctrl$indexOut))
-    stop("`ctrl$indexOut` should be populated with integers", call. = FALSE)
+  if (is.null(data)) {
+    cli_abort("Must supply original data")
+  }
+  if (!any(names(ctrl) == "index")) {
+    cli_abort("{.arg ctrl} should have an element {.val index}")
+  }
+  if (!any(names(ctrl) == "indexOut")) {
+    cli_abort("{.arg ctrl} should have an element {.val indexOut}")
+  }
+  if (is.null(ctrl$index)) {
+    cli_abort("{.val ctrl$index} should be populated with integers")
+  }
+  if (is.null(ctrl$indexOut)) {
+    cli_abort("{.val ctrl$indexOut} should be populated with integers")
+  }
 
   indices <- purrr::map2(ctrl$index, ctrl$indexOut, extract_int)
   id_data <- names(indices)
@@ -51,27 +57,32 @@ caret2rsample <- function(ctrl, data = NULL) {
   if (ctrl$method %in% c("repeatedcv", "adaptive_cv")) {
     id_data <- strsplit(id_data, split = ".", fixed = TRUE)
     id_data <- tibble::tibble(
-      id  = vapply(id_data, function(x)
-        x[2], character(1)),
-      id2 = vapply(id_data, function(x)
-        x[1], character(1))
+      id = vapply(id_data, function(x) {
+        x[2]
+      }, character(1)),
+      id2 = vapply(id_data, function(x) {
+        x[1]
+      }, character(1))
     )
   } else {
     id_data <- tibble::tibble(id = id_data)
   }
 
-  new_rset(splits = indices$splits,
-           ids = id_data[, grepl("^id", names(id_data))],
-           attrib = map_attr(ctrl),
-           subclass = c(map_rset_method(ctrl$method), "rset"))
-
+  new_rset(
+    splits = indices$splits,
+    ids = id_data[, grepl("^id", names(id_data))],
+    attrib = map_attr(ctrl),
+    subclass = c(map_rset_method(ctrl$method), "rset")
+  )
 }
 
-extract_int <- function(x, y)
+extract_int <- function(x, y) {
   list(in_id = x, out_id = y)
+}
 
-add_data <- function(x, y)
+add_data <- function(x, y) {
   c(list(data = y), x)
+}
 
 add_rsplit_class <- function(x, cl) {
   class(x) <- c("rsplit", cl)
@@ -86,54 +97,73 @@ add_rset_class <- function(x, cl) {
 map_rsplit_method <- function(method) {
   out <- switch(
     method,
-    cv = , repeatedcv = , adaptive_cv = "vfold_split",
-    boot = , boot_all =, boot632 = , optimism_boot = , adaptive_boot = "boot_split",
+    cv = ,
+    repeatedcv = ,
+    adaptive_cv = "vfold_split",
+    boot = ,
+    boot_all = ,
+    boot632 = ,
+    optimism_boot = ,
+    adaptive_boot = "boot_split",
     LOOCV = "loo_split",
-    LGOCV = , adaptive_LGOCV = "mc_split",
+    LGOCV = ,
+    adaptive_LGOCV = "mc_split",
     timeSlice = "rof_split",
     "error"
   )
-  if (out == "error")
-    stop("Resampling method `",
-         method,
-         "` cannot be converted into an `rsplit` object",
-         call. = FALSE)
+  if (out == "error") {
+    cli_abort(
+      "Resampling method {.arg method} cannot be converted into an {.cls rsplit} object"
+    )
+  }
   out
 }
 
 map_rset_method <- function(method) {
   out <- switch(
     method,
-    cv = , repeatedcv = , adaptive_cv = "vfold_cv",
-    boot = , boot_all =, boot632 = , optimism_boot = , adaptive_boot = "bootstraps",
+    cv = ,
+    repeatedcv = ,
+    adaptive_cv = "vfold_cv",
+    boot = ,
+    boot_all = ,
+    boot632 = ,
+    optimism_boot = ,
+    adaptive_boot = "bootstraps",
     LOOCV = "loo_cv",
-    LGOCV = , adaptive_LGOCV = "mc_cv",
+    LGOCV = ,
+    adaptive_LGOCV = "mc_cv",
     timeSlice = "rolling_origin",
     "error"
   )
-  if (out == "error")
-    stop("Resampling method `",
-         method,
-         "` cannot be converted into an `rset` object",
-         call. = FALSE)
+  if (out == "error") {
+    cli_abort("Resampling method {.arg method} cannot be converted into an {.cls rset} object")
+  }
   out
 }
 
 
 map_attr <- function(object) {
   if (grepl("cv$", object$method)) {
-    out <- list(v = object$number,
-                repeats = ifelse(!is.na(object$repeats),
-                             object$repeats, 1),
-                strata = TRUE)
+    out <- list(
+      v = object$number,
+      repeats = ifelse(!is.na(object$repeats),
+                       object$repeats, 1
+      ),
+      strata = TRUE
+    )
   } else if (grepl("boot", object$method)) {
-    out <- list(times = object$number,
-                apparent = FALSE,
-                strata = FALSE)
+    out <- list(
+      times = object$number,
+      apparent = FALSE,
+      strata = FALSE
+    )
   } else if (grepl("LGOCV$", object$method)) {
-    out <- list(times = object$number,
-                prop = object$p,
-                strata = FALSE)
+    out <- list(
+      times = object$number,
+      prop = object$p,
+      strata = FALSE
+    )
   } else if (object$method == "LOOCV") {
     out <- list()
   } else if (object$method == "timeSlice") {
@@ -144,8 +174,7 @@ map_attr <- function(object) {
       skip = object$skip
     )
   } else {
-    stop("Method", object$method, "cannot be converted")
+    cli_abort("Method {.arg object$method} cannot be converted")
   }
   out
 }
-
