@@ -12,7 +12,8 @@
 #' loo_cv(mtcars)
 #' @export
 loo_cv <- function(data, ...) {
-  split_objs <- vfold_splits(data = data, v = nrow(data))
+  check_dots_empty()
+  split_objs <- vfold_splits(data = data, v = nrow(data), prevent_loo = FALSE)
   split_objs <-
     list(
       splits = map(split_objs$splits, change_class),
