@@ -51,12 +51,15 @@
 #' @export
 mc_cv <- function(data, prop = 3 / 4, times = 25,
                   strata = NULL, breaks = 4, pool = 0.1, ...) {
+  check_dots_empty()
+  check_prop(prop)
+
   if (!missing(strata)) {
     strata <- tidyselect::vars_select(names(data), !!enquo(strata))
     if (length(strata) == 0) strata <- NULL
   }
 
-  strata_check(strata, data)
+  check_strata(strata, data)
 
   split_objs <-
     mc_splits(
@@ -101,10 +104,6 @@ mc_complement <- function(ind, n) {
 
 mc_splits <- function(data, prop = 3 / 4, times = 25,
                       strata = NULL, breaks = 4, pool = 0.1) {
-  if (!is.numeric(prop) | prop >= 1 | prop <= 0) {
-    rlang::abort("`prop` must be a number on (0, 1).")
-  }
-
   n <- nrow(data)
   if (is.null(strata)) {
     indices <- purrr::map(rep(n, times), sample, size = floor(n * prop))
@@ -118,7 +117,8 @@ mc_splits <- function(data, prop = 3 / 4, times = 25,
     )
     stratas <- split_unnamed(stratas, stratas$strata)
     stratas <-
-      purrr::map_df(stratas, strat_sample, prop = prop, times = times)
+      purrr::map(stratas, strat_sample, prop = prop, times = times) %>%
+      list_rbind()
     indices <- split_unnamed(stratas$idx, stratas$rs_id)
   }
   indices <- lapply(indices, mc_complement, n = n)
@@ -133,7 +133,8 @@ mc_splits <- function(data, prop = 3 / 4, times = 25,
 strat_sample <- function(x, prop, times, ...) {
   n <- nrow(x)
   idx <- purrr::map(rep(n, times), sample, size = floor(n * prop), ...)
-  out <- purrr::map_df(idx, function(ind, x) x[sort(ind), "idx"], x = x)
+  out <- purrr::map(idx, function(ind, x) x[sort(ind), "idx"], x = x) %>%
+    list_rbind()
   out$rs_id <- rep(1:times, each = floor(n * prop))
   out
 }
@@ -165,7 +166,8 @@ strat_sample <- function(x, prop, times, ...) {
 group_mc_cv <- function(data, group, prop = 3 / 4, times = 25, ...,
                         strata = NULL, pool = 0.1) {
 
-  rlang::check_dots_empty()
+  check_dots_empty()
+  check_prop(prop)
 
   group <- validate_group({{ group }}, data)
 
@@ -235,12 +237,12 @@ group_mc_splits <- function(data, group, prop = 3 / 4, times = 25, strata = NULL
       indices,
       make_splits,
       data = data,
-      class = c("grouped_mc_split", "mc_split")
+      class = c("group_mc_split", "mc_split")
     )
 
   all_assessable <- purrr::map(split_objs, function(x) nrow(assessment(x)))
   if (any(all_assessable == 0)) {
-    rlang::abort(
+    cli_abort(
       c(
         "Some assessment sets contained zero rows",
         i = "Consider using a non-grouped resampling method"
