@@ -1,4 +1,4 @@
-## The `pretty` methods below are good for when you need to
+## The `pretty()` methods below are good for when you need to
 ## textually describe the resampling procedure. Note that they
 ## can have more than one element (in the case of nesting)
 
@@ -55,14 +55,27 @@ pretty.mc_cv <- function(x, ...) {
     signif(1 - details$prop, 2),
     ") with ",
     details$times,
-    " resamples "
+    " resamples"
   )
   if (has_strata(details)) {
-    res <- paste(res, "using stratification")
+    res <- paste(res, " using stratification")
   }
   res
 }
 
+#' @export
+pretty.validation_set <- function(x, ...) {
+  details <- attributes(x)
+  res <- paste0(
+    "Validation Set (",
+    signif(details$prop[1] / sum(details$prop), 2),
+    "/",
+    signif(details$prop[2] / sum(details$prop), 2),
+    ")"
+  )
+  res
+}
+
 #' @export
 pretty.validation_split <- function(x, ...) {
   details <- attributes(x)
@@ -90,7 +103,7 @@ pretty.group_validation_split <- function(x, ...) {
     ") "
   )
   if (has_strata(details)) {
-    res <- paste(res, "using stratification")
+    res <- paste0(res, "using stratification")
   }
   res
 }
@@ -176,6 +189,10 @@ pretty.group_mc_cv <- function(x, ...) {
     " resamples "
   )
 
+  if (has_strata(details)) {
+    res <- paste0(res, "using stratification")
+  }
+
   res
 }
 
@@ -184,6 +201,12 @@ pretty.manual_rset <- function(x, ...) {
   "Manual resampling"
 }
 
+#' @export
+pretty.clustering_cv <- function(x, ...) {
+  details <- attributes(x)
+  paste0(details$v, "-cluster cross-validation")
+}
+
 # The print methods below control the display of rset objects
 
 #' @export
@@ -357,6 +380,13 @@ print.vfold_cv <- function(x, ...) {
   print(x, ...)
 }
 
+#' @export
+print.clustering_cv <- function(x, ...) {
+  cat("#", pretty(x), "\n")
+  class(x) <- class(x)[!(class(x) %in% c("clustering_cv", "rset"))]
+  print(x, ...)
+}
+
 has_strata <- function(x) {
   !is.null(x$strata) && !identical(x$strata, FALSE)
 }
