@@ -1,20 +1,20 @@
 rsplit <- function(data, in_id, out_id) {
   if (!is.data.frame(data) & !is.matrix(data)) {
-    rlang::abort("`data` must be a data frame.")
+    cli_abort("{.arg data} must be a data frame.")
   }
 
   if (!is.integer(in_id) | any(in_id < 1)) {
-    rlang::abort("`in_id` must be a positive integer vector.")
+    cli_abort("{.arg in_id} must be a positive integer vector.")
   }
 
   if (!all(is.na(out_id))) {
     if (!is.integer(out_id) | any(out_id < 1)) {
-      rlang::abort("`out_id` must be a positive integer vector.")
+      cli_abort("{.arg out_id} must be a positive integer vector.")
     }
   }
 
   if (length(in_id) == 0) {
-    rlang::abort("At least one row should be selected for the analysis set.")
+    cli_abort("At least one row should be selected for the analysis set.")
   }
 
   structure(
@@ -66,13 +66,13 @@ as.integer.rsplit <-
 #'
 #' The analysis or assessment code can be returned as a data
 #'   frame (as dictated by the `data` argument) using
-#'   `as.data.frame.rsplit`. `analysis` and
-#'   `assessment` are shortcuts.
+#'   `as.data.frame.rsplit()`. `analysis()` and
+#'   `assessment()` are shortcuts.
 #' @param x An `rsplit` object.
 #' @param row.names `NULL` or a character vector giving the row names for the data frame. Missing values are not allowed.
 #' @param optional A logical: should the column names of the data be checked for legality?
-#' @param data Either "analysis" or "assessment" to specify which data are returned.
-#' @param ...	Additional arguments to be passed to or from methods. Not currently used.
+#' @param data Either `"analysis"` or `"assessment"` to specify which data are returned.
+#' @param ... Not currently used.
 #' @examples
 #' library(dplyr)
 #' set.seed(104)
@@ -88,49 +88,74 @@ as.data.frame.rsplit <-
            data = "analysis",
            ...) {
     if (!is.null(row.names)) {
-      rlang::warn(paste0(
-        "`row.names` is kept for consistency with the underlying class but ",
-        "non-NULL values will be ignored."
-      ))
+      cli::cli_warn(
+        "{.arg row.names} is kept for consistency with the underlying class but 
+        non-NULL values will be ignored."
+      )
     }
     if (optional) {
-      rlang::warn(paste0(
-        "`optional` is kept for consistency with the underlying class but ",
-        "TRUE values will be ignored."
-      ))
+      cli::cli_warn(
+        "{.arg optional} is kept for consistency with the underlying class but
+        TRUE values will be ignored."
+      )
 
     }
     if (!is.null(x$col_id)) {
       if (identical(data, "assessment")) {
         rsplit_class <- class(x)[[1]]
-        msg <- paste0(
-          "There is no assessment data set for an `rsplit` object",
-          " with class `", rsplit_class, "`."
+        cli_abort(
+          "There is no assessment data set for an {.arg rsplit} object
+          with class {.cls {rsplit_class}}."
         )
-        rlang::abort(msg)
       }
-      permuted_col <-
-        x$data[as.integer(x, data = data, ...), x$col_id, drop = FALSE]
+      ind <- as.integer(x, data = data, ...)
+      permuted_col <- vctrs::vec_slice(x$data, ind) %>%
+        dplyr::select(x$col_id)
       x$data[, x$col_id] <- permuted_col
       return(x$data)
     }
-    x$data[as.integer(x, data = data, ...), , drop = FALSE]
+    row_ind <- as.integer(x, data = data, ...)
+    vctrs::vec_slice(x$data, row_ind)
   }
 
 #' @rdname as.data.frame.rsplit
 #' @export
 analysis <- function(x, ...) {
-  if (!inherits(x, "rsplit")) {
-    rlang::abort("`x` should be an `rsplit` object")
-  }
+  UseMethod("analysis")
+}
+
+#' @export
+#' @rdname as.data.frame.rsplit
+analysis.default <- function(x, ...) {
+  cls <- class(x)
+  cli::cli_abort(
+    "No method for objects of class{?es}: {cls}"
+  )
+}
+
+#' @export
+#' @rdname as.data.frame.rsplit
+analysis.rsplit <- function(x, ...) {
   as.data.frame(x, data = "analysis", ...)
 }
 #' @rdname as.data.frame.rsplit
 #' @export
 assessment <- function(x, ...) {
-  if (!inherits(x, "rsplit")) {
-    rlang::abort("`x` should be an `rsplit` object")
-  }
+  UseMethod("assessment")
+}
+
+#' @export
+#' @rdname as.data.frame.rsplit
+assessment.default <- function(x, ...) {
+  cls <- class(x)
+  cli::cli_abort(
+    "No method for objects of class{?es}: {cls}"
+  )
+}
+
+#' @rdname as.data.frame.rsplit
+#' @export
+assessment.rsplit <- function(x, ...) {
   as.data.frame(x, data = "assessment", ...)
 }
 
