@@ -19,7 +19,7 @@
 #'   This is extremely useful for constructing rolling monthly or yearly
 #'   windows from daily data.
 #'
-#' @inheritParams ellipsis::dots_empty
+#' @inheritParams rlang::args_dots_empty
 #'
 #' @param data A data frame.
 #'
@@ -37,7 +37,7 @@
 #'
 #' @param period The period to group the `index` by. This is specified as a
 #'   single string, such as `"year"` or `"month"`. See the `.period` argument
-#'   of [slider::slide_index()] for the full list of options and further
+#'   of [slider::slide_period()] for the full list of options and further
 #'   explanation.
 #'
 #' @param lookback The number of elements to look back from the current element
@@ -127,7 +127,7 @@
 #'
 #' @name slide-resampling
 #'
-#' @examples
+#' @examplesIf rlang::is_installed("modeldata")
 #' library(vctrs)
 #' library(tibble)
 #' library(modeldata)
@@ -213,10 +213,10 @@ sliding_window <- function(data,
                            complete = TRUE,
                            step = 1L,
                            skip = 0L) {
-  ellipsis::check_dots_empty()
+  rlang::check_dots_empty()
 
   if (!is.data.frame(data)) {
-    rlang::abort("`data` must be a data frame.")
+    cli_abort("{.arg data} must be a data frame.")
   }
 
   lookback <- check_lookback(lookback)
@@ -226,7 +226,7 @@ sliding_window <- function(data,
   skip <- check_skip(skip)
 
   if (assess_start > assess_stop) {
-    rlang::abort("`assess_start` must be less than or equal to `assess_stop`.")
+    cli_abort("{.arg assess_start} must be less than or equal to {.arg assess_stop}.")
   }
 
   seq <- vctrs::vec_seq_along(data)
@@ -296,10 +296,10 @@ sliding_index <- function(data,
                           complete = TRUE,
                           step = 1L,
                           skip = 0L) {
-  ellipsis::check_dots_empty()
+  rlang::check_dots_empty()
 
   if (!is.data.frame(data)) {
-    rlang::abort("`data` must be a data frame.")
+    cli_abort("{.arg data} must be a data frame.")
   }
 
   step <- check_step(step)
@@ -309,9 +309,10 @@ sliding_index <- function(data,
   loc <- tidyselect::eval_select(index, data)
 
   if (length(loc) != 1L) {
-    rlang::abort("`index` must specify exactly one column in `data`.")
+    cli_abort("{.arg index} must specify exactly one column in {.arg data}.")
   }
 
+  index_attrib <- index
   index <- data[[loc]]
 
   seq <- vctrs::vec_seq_along(data)
@@ -352,6 +353,7 @@ sliding_index <- function(data,
   ids <- names0(length(indices), prefix = "Slice")
 
   attrib <- list(
+    index = index_attrib,
     lookback = lookback,
     assess_start = assess_start,
     assess_stop = assess_stop,
@@ -384,10 +386,10 @@ sliding_period <- function(data,
                            skip = 0L,
                            every = 1L,
                            origin = NULL) {
-  ellipsis::check_dots_empty()
+  rlang::check_dots_empty()
 
   if (!is.data.frame(data)) {
-    rlang::abort("`data` must be a data frame.")
+    cli_abort("{.arg data} must be a data frame.")
   }
 
   lookback <- check_lookback(lookback)
@@ -396,16 +398,17 @@ sliding_period <- function(data,
   step <- check_step(step)
 
   if (assess_start > assess_stop) {
-    rlang::abort("`assess_start` must be less than or equal to `assess_stop`.")
+    cli_abort("{.arg assess_start} must be less than or equal to {.arg assess_stop}.")
   }
 
   index <- rlang::enexpr(index)
   loc <- tidyselect::eval_select(index, data)
 
   if (length(loc) != 1L) {
-    rlang::abort("`index` must specify exactly one column in `data`.")
+    cli_abort("{.arg index} must specify exactly one column in {.arg data}.")
   }
 
+  index_attrib <- index
   index <- data[[loc]]
 
   seq <- vctrs::vec_seq_along(data)
@@ -452,6 +455,7 @@ sliding_period <- function(data,
   ids <- names0(length(indices), prefix = "Slice")
 
   attrib <- list(
+    index = index_attrib,
     period = period,
     lookback = lookback,
     assess_start = assess_start,
@@ -475,7 +479,7 @@ sliding_period <- function(data,
 
 check_lookback <- function(x) {
   if (vctrs::vec_size(x) != 1L) {
-    rlang::abort(paste0("`lookback` must have size 1."))
+    cli_abort("{.arg lookback} must have size 1.")
   }
 
   if (identical(x, Inf)) {
@@ -483,11 +487,11 @@ check_lookback <- function(x) {
   }
 
   if (!rlang::is_integerish(x, finite = TRUE)) {
-    rlang::abort(paste0("`lookback` must be an integer of size 1, or `Inf`."))
+    cli_abort("{.arg lookback} must be an integer of size 1, or {.arg Inf}.")
   }
 
   if (x < 0L) {
-    rlang::abort(paste0("`lookback` must be positive, or zero."))
+    cli_abort("{.arg lookback} must be positive, or zero.")
   }
 
   vctrs::vec_cast(x, integer(), x_arg = "lookback")
@@ -495,7 +499,7 @@ check_lookback <- function(x) {
 
 check_assess <- function(x, arg) {
   if (vctrs::vec_size(x) != 1L) {
-    rlang::abort(paste0("`", arg, "` must have size 1."))
+    cli_abort("{.arg {arg}} must have size 1.")
   }
 
   if (identical(x, Inf)) {
@@ -503,11 +507,11 @@ check_assess <- function(x, arg) {
   }
 
   if (!rlang::is_integerish(x, finite = TRUE)) {
-    rlang::abort(paste0("`", arg, "` must be an integer of size 1, or `Inf`."))
+    cli_abort("{.arg {arg}} must be an integer of size 1, or {.code Inf}.")
   }
 
   if (x <= 0L) {
-    rlang::abort(paste0("`", arg, "` must be positive."))
+    cli_abort("{.arg {arg}} must be positive.")
   }
 
   vctrs::vec_cast(x, integer(), x_arg = arg)
@@ -515,15 +519,15 @@ check_assess <- function(x, arg) {
 
 check_step <- function(x) {
   if (vctrs::vec_size(x) != 1L) {
-    rlang::abort(paste0("`step` must have size 1."))
+    cli_abort("{.arg step} must have size 1.")
   }
 
   if (!rlang::is_integerish(x, finite = TRUE)) {
-    rlang::abort(paste0("`step` must be an integer of size 1."))
+    cli_abort("{.arg step} must be an integer of size 1.")
   }
 
   if (x <= 0L) {
-    rlang::abort(paste0("`step` must be positive."))
+    cli_abort("{.arg step} must be positive.")
   }
 
   vctrs::vec_cast(x, integer(), x_arg = "step")
@@ -531,15 +535,15 @@ check_step <- function(x) {
 
 check_skip <- function(x) {
   if (vctrs::vec_size(x) != 1L) {
-    rlang::abort(paste0("`skip` must have size 1."))
+    cli_abort("{.arg skip} must have size 1.")
   }
 
   if (!rlang::is_integerish(x, finite = TRUE)) {
-    rlang::abort(paste0("`skip` must be an integer of size 1."))
+    cli_abort("{.arg skip}` must be an integer of size 1.")
   }
 
   if (x < 0L) {
-    rlang::abort(paste0("`skip` must be positive, or zero."))
+    cli_abort("{.arg skip} must be positive, or zero.")
   }
 
   vctrs::vec_cast(x, integer(), x_arg = "skip")
@@ -548,8 +552,8 @@ check_skip <- function(x) {
 compute_complete_indices <- function(id_in, id_out) {
   # Remove where either list has a `NULL` element.
   # These are incomplete windows.
-  id_in_na <- vctrs::vec_equal_na(id_in)
-  id_out_na <- vctrs::vec_equal_na(id_out)
+  id_in_na <- vctrs::vec_detect_missing(id_in)
+  id_out_na <- vctrs::vec_detect_missing(id_out)
 
   id_either_na <- id_in_na | id_out_na
 
@@ -573,19 +577,19 @@ slice_step <- function(indices, step) {
 
 seq2_by <- function(from, to, by) {
   if (length(from) != 1) {
-    rlang::abort("`from` must be length one")
+    cli_abort("{.arg from} must be length one")
   }
   if (length(to) != 1) {
-    rlang::abort("`to` must be length one")
+    cli_abort("{.arg to} must be length one")
   }
 
   by <- as.integer(by)
 
   if (length(by) != 1) {
-    rlang::abort("`by` must be length one")
+    cli_abort("{.arg by} must be length one")
   }
   if (by <= 0L) {
-    rlang::abort("`by` must be positive")
+    cli_abort("{.arg by} must be positive")
   }
 
   if (from > to) {
