@@ -1,5 +1,15 @@
 #' Create a Validation Set
 #'
+#' @description
+#' `r lifecycle::badge('deprecated')`
+#'
+#' This function is deprecated because it's part of an approach to constructing
+#' a training, validation, and testing set by doing a sequence of two binary
+#' splits: testing / not-testing (with [initial_split()] or one of its variants)
+#' and then not-testing split into training/validation with `validation_split()`.
+#' Instead, now use [initial_validation_split()] or one if its variants to
+#' construct the three sets via one 3-way split.
+#'
 #' `validation_split()` takes a single random sample (without replacement) of
 #'  the original data set to be used for analysis. All other data points are
 #'  added to the assessment set (to be used as the validation set).
@@ -8,6 +18,12 @@
 #'  `group_validation_split()` creates splits of the data based
 #'  on some grouping variable, so that all data in a "group" is assigned to
 #'  the same split.
+#'
+#'  Note that the input `data` to `validation_split()`, `validation_time_split()`,
+#'  and `group_validation_split()` should _not_ contain the testing data. To
+#'  create a three-way split directly of the entire data set, use
+#'  [initial_validation_split()].
+#'
 #' @template strata_details
 #' @inheritParams vfold_cv
 #' @inheritParams make_strata
@@ -17,16 +33,34 @@
 #'  and `data.frame`. The results include a column for the data split objects
 #'  and a column called `id` that has a character string with the resample
 #'  identifier.
+#'
+#' @seealso [initial_validation_split()], [group_initial_validation_split()],
+#' [validation_set()]
+#'
+#' @keywords internal
 #' @examplesIf rlang::is_installed("modeldata")
-#' validation_split(mtcars, prop = .9)
+#' cars_split <- initial_split(mtcars)
+#' cars_not_testing <- training(cars_split)
+#' validation_split(cars_not_testing, prop = .9)
+#' group_validation_split(cars_not_testing, cyl)
 #'
 #' data(drinks, package = "modeldata")
-#' validation_time_split(drinks)
+#' validation_time_split(drinks[1:200,])
 #'
-#' group_validation_split(mtcars, cyl)
-#' @export
+#' # Alternative
+#' cars_split_3 <- initial_validation_split(mtcars)
+#' validation_set(cars_split_3)
 validation_split <- function(data, prop = 3 / 4,
                              strata = NULL, breaks = 4, pool = 0.1, ...) {
+  lifecycle::deprecate_warn(
+    "1.2.0",
+    "validation_split()",
+    "initial_validation_split()"
+  )
+
+  check_dots_empty()
+  check_prop(prop)
+
   if (!missing(strata)) {
     strata <- tidyselect::vars_select(names(data), !!enquo(strata))
     if (length(strata) == 0) {
@@ -34,7 +68,7 @@ validation_split <- function(data, prop = 3 / 4,
     }
   }
 
-  strata_check(strata, data)
+  check_strata(strata, data)
 
   split_objs <-
     mc_splits(
@@ -73,6 +107,15 @@ validation_split <- function(data, prop = 3 / 4,
 #' @inheritParams initial_time_split
 #' @export
 validation_time_split <- function(data, prop = 3 / 4, lag = 0, ...) {
+  lifecycle::deprecate_warn(
+    "1.2.0",
+    "validation_time_split()",
+    "initial_validation_time_split()"
+  )
+
+  check_dots_empty()
+
+  check_prop(prop)
   if (!is.numeric(prop) | prop >= 1 | prop <= 0) {
     rlang::abort("`prop` must be a number on (0, 1).")
   }
@@ -88,7 +131,6 @@ validation_time_split <- function(data, prop = 3 / 4, lag = 0, ...) {
   }
 
   split <- rsplit(data, 1:n_train, (n_train + 1 - lag):nrow(data))
-  split <- rm_out(split)
   class(split) <- c("val_time_split", "val_split", "rsplit")
   splits <- list(split)
 
@@ -105,18 +147,30 @@ validation_time_split <- function(data, prop = 3 / 4, lag = 0, ...) {
 #' @rdname validation_split
 #' @inheritParams group_initial_split
 #' @export
-group_validation_split <- function(data, group, prop = 3 / 4, ...) {
+group_validation_split <- function(data, group, prop = 3 / 4, ..., strata = NULL, pool = 0.1) {
+  lifecycle::deprecate_warn(
+    "1.2.0",
+    "group_validation_split()",
+    "group_initial_validation_split()"
+  )
 
-  rlang::check_dots_empty()
+  check_dots_empty()
 
   group <- validate_group({{ group }}, data)
+  check_prop(prop)
+
+  if (!missing(strata)) {
+    strata <- check_grouped_strata({{ group }}, {{ strata }}, pool, data)
+  }
 
   split_objs <-
     group_mc_splits(
       data = data,
       group = {{ group }},
       prop = prop,
-      times = 1
+      times = 1,
+      strata = {{ strata }},
+      pool = pool
     )
 
   ## We remove the holdout indices since it will save space and we can
@@ -125,10 +179,13 @@ group_validation_split <- function(data, group, prop = 3 / 4, ...) {
   split_objs$splits <- map(split_objs$splits, rm_out)
   class(split_objs$splits[[1]]) <- c("group_val_split", "val_split", "rsplit")
 
+  # This is needed for printing -- strata cannot be missing
+  if (is.null(strata)) strata <- FALSE
   val_att <- list(
     prop = prop,
     group = group,
-    strata = FALSE
+    strata = strata,
+    pool = pool
   )
 
   new_rset(
@@ -138,4 +195,3 @@ group_validation_split <- function(data, group, prop = 3 / 4, ...) {
     subclass = c("group_validation_split", "validation_split", "group_rset", "rset")
   )
 }
-
