@@ -17,7 +17,7 @@
 #' @param strata A variable in `data` (single character or name) used to conduct
 #'  stratified sampling. When not `NULL`, each resample is created within the
 #'  stratification variable. Numeric `strata` are binned into quartiles.
-#' @param ... Not currently used.
+#' @inheritParams rlang::args_dots_empty
 #' @export
 #' @return A tibble with classes `vfold_cv`, `rset`, `tbl_df`, `tbl`, and
 #'  `data.frame`. The results include a column for the data split objects and
@@ -65,12 +65,14 @@
 #' @export
 vfold_cv <- function(data, v = 10, repeats = 1,
                      strata = NULL, breaks = 4, pool = 0.1, ...) {
+  check_dots_empty()
   if (!missing(strata)) {
     strata <- tidyselect::vars_select(names(data), !!enquo(strata))
     if (length(strata) == 0) strata <- NULL
   }
 
-  strata_check(strata, data)
+  check_strata(strata, data)
+  check_number_whole(repeats, min = 1)
 
   if (repeats == 1) {
     split_objs <- vfold_splits(
@@ -79,12 +81,12 @@ vfold_cv <- function(data, v = 10, repeats = 1,
     )
   } else {
     if (v == nrow(data)) {
-      rlang::abort(
-        glue::glue("Repeated resampling when `v` is {v} would create identical resamples")
+      cli_abort(
+        "Repeated resampling when {.arg v} is {v} would create identical resamples."
       )
     }
     for (i in 1:repeats) {
-      tmp <- vfold_splits(data = data, v = v, strata = strata, pool = pool)
+      tmp <- vfold_splits(data = data, v = v, strata = strata, breaks = breaks ,pool = pool)
       tmp$id2 <- tmp$id
       tmp$id <- names0(repeats, "Repeat")[i]
       split_objs <- if (i == 1) {
@@ -120,10 +122,10 @@ vfold_cv <- function(data, v = 10, repeats = 1,
 }
 
 
-vfold_splits <- function(data, v = 10, strata = NULL, breaks = 4, pool = 0.1) {
+vfold_splits <- function(data, v = 10, strata = NULL, breaks = 4, pool = 0.1, prevent_loo = TRUE) {
 
   n <- nrow(data)
-  check_v(v, n, call = rlang::caller_env())
+  check_v(v, n, prevent_loo = prevent_loo, call = rlang::caller_env())
 
   if (is.null(strata)) {
     folds <- sample(rep(1:v, length.out = n))
@@ -194,27 +196,45 @@ vfold_splits <- function(data, v = 10, strata = NULL, breaks = 4, pool = 0.1) {
 #' # Leave-one-group-out CV
 #' group_vfold_cv(ames, group = Neighborhood)
 #'
+#' library(dplyr)
+#' data(Sacramento, package = "modeldata")
+#'
+#' city_strata <- Sacramento %>%
+#'   group_by(city) %>%
+#'   summarize(strata = mean(price)) %>%
+#'   summarize(city = city,
+#'             strata = cut(strata, quantile(strata), include.lowest = TRUE))
+#'
+#' sacramento_data <- Sacramento %>%
+#'   full_join(city_strata, by = "city")
+#'
+#' group_vfold_cv(sacramento_data, city, strata = strata)
+#'
 #' @export
-group_vfold_cv <- function(data, group = NULL, v = NULL, repeats = 1, balance = c("groups", "observations"), ...) {
-
+group_vfold_cv <- function(data, group = NULL, v = NULL, repeats = 1, balance = c("groups", "observations"), ..., strata = NULL, pool = 0.1) {
+  check_dots_empty()
+  check_number_whole(repeats, min = 1)
   group <- validate_group({{ group }}, data)
   balance <- rlang::arg_match(balance)
 
+  if (!missing(strata)) {
+    strata <- check_grouped_strata({{ group }}, {{ strata }}, pool, data)
+  }
+
   if (repeats == 1) {
-    split_objs <- group_vfold_splits(data = data, group = group, v = v, balance = balance)
+    split_objs <- group_vfold_splits(data = data, group = group, v = v, balance = balance, strata = strata, pool = pool)
   } else {
     if (is.null(v)) {
-      rlang::abort(
-        "Repeated resampling when `v` is `NULL` would create identical resamples"
+     cli_abort(
+        "Repeated resampling when {.arg v} is {.val NULL} would create identical resamples."
       )
     }
     if (v == length(unique(getElement(data, group)))) {
-      rlang::abort(
-        glue::glue("Repeated resampling when `v` is {v} would create identical resamples")
-      )
+      cli_abort("Repeated resampling when {.arg v} is {.val {v}} would create identical resamples.")
+
     }
     for (i in 1:repeats) {
-      tmp <- group_vfold_splits(data = data, group = group, v = v, balance = balance)
+      tmp <- group_vfold_splits(data = data, group = group, v = v, balance = balance, strata = strata, pool = pool)
       tmp$id2 <- tmp$id
       tmp$id <- names0(repeats, "Repeat")[i]
       split_objs <- if (i == 1) {
@@ -237,7 +257,7 @@ group_vfold_cv <- function(data, group = NULL, v = NULL, repeats = 1, balance =
 
   ## Save some overall information
 
-  cv_att <- list(v = v, group = group, balance = balance, repeats = 1, strata = FALSE)
+  cv_att <- list(v = v, group = group, balance = balance, repeats = 1, strata = strata, pool = pool)
 
   new_rset(
     splits = split_objs$splits,
@@ -247,18 +267,51 @@ group_vfold_cv <- function(data, group = NULL, v = NULL, repeats = 1, balance =
   )
 }
 
-group_vfold_splits <- function(data, group, v = NULL, balance) {
+group_vfold_splits <- function(data, group, v = NULL, balance, strata = NULL, pool = 0.1) {
 
   group <- getElement(data, group)
   max_v <- length(unique(group))
+  if (!is.null(strata)) {
+    strata <- getElement(data, strata)
+    strata <- as.character(strata)
+    strata <- make_strata(strata, pool = pool)
+
+    if (is.null(v)) {
+      # Set max_v to be the lowest number of groups in a single strata
+      # to ensure that all folds get each strata
+      max_v <- min(
+        vec_count(
+          vec_unique(
+            data.frame(group, strata)
+          )$strata
+        )$count
+      )
+      message <- c(
+        "Leaving {.code v = NULL} while using stratification will set {.arg v} to the number of groups present in the least common stratum."
+      )
+
+      if (max_v < 5) {
+        cli_abort(c(
+          message,
+          "*" = "The least common stratum only had {.val {max_v}} groups, which may not be enough for cross-validation.",
+          "i" = "Set {.arg v} explicitly to override this error."
+        ), call = rlang::caller_env())
+      }
+
+      cli_warn(c(
+        message,
+        i = "Set {.arg v} explicitly to override this warning."
+      ),
+      call = rlang::caller_env())
+    }
+  }
 
   if (is.null(v)) {
     v <- max_v
-  } else {
-    check_v(v = v, max_v = max_v, rows = "groups", call = rlang::caller_env())
   }
+  check_v(v = v, max_v = max_v, rows = "groups", prevent_loo = FALSE, call = rlang::caller_env())
 
-  indices <- make_groups(data, group, v, balance)
+  indices <- make_groups(data, group, v, balance, strata)
   indices <- lapply(indices, default_complement, n = nrow(data))
   split_objs <-
     purrr::map(indices,
@@ -277,12 +330,45 @@ add_vfolds <- function(x, v) {
   x
 }
 
-check_v <- function(v, max_v, rows = "rows", call = rlang::caller_env()) {
-  if (!is.numeric(v) || length(v) != 1 || v < 0) {
-    rlang::abort("`v` must be a single positive integer", call = call)
-  } else if (v > max_v) {
-    rlang::abort(
-      glue::glue("The number of {rows} is less than `v = {v}`"), call = call
+check_v <- function(v, max_v, rows = "rows", prevent_loo = TRUE, call = rlang::caller_env()) {
+  check_number_whole(v, min = 2, call = call)
+
+  if (v > max_v) {
+    cli_abort(
+      "The number of {rows} is less than {.arg v} = {.val {v}}.",
+      call = call
     )
+  } 
+  if (prevent_loo && isTRUE(v == max_v)) {
+    cli_abort(c(
+      "Leave-one-out cross-validation is not supported by this function.",
+      "x" = "You set {.arg v} to {.code nrow(data)}, which would result in a leave-one-out cross-validation.",
+      "i" = "Use {.fn loo_cv} in this case."
+    ), call = call)
   }
 }
+
+check_grouped_strata <- function(group, strata, pool, data, call = caller_env()) {
+
+  strata <- tidyselect::vars_select(names(data), !!enquo(strata))
+
+  # if strata was NULL this is empty, thus return NULL
+  if (length(strata) < 1) {
+    return(NULL)
+  }
+
+  grouped_table <- tibble(
+    group = getElement(data, group),
+    strata = getElement(data, strata)
+  )
+
+  if (nrow(vctrs::vec_unique(grouped_table)) !=
+      nrow(vctrs::vec_unique(grouped_table["group"]))) {
+    cli_abort(
+      "{.field strata} must be constant across all members of each {.field group}.",
+      call = call
+    )
+  }
+
+  strata
+}
