@@ -101,14 +101,63 @@ test_that("strata", {
   expect_equal(res5, warpbreaks)
 })
 
+test_that("grouping -- strata", {
+  set.seed(11)
+
+  n_common_class <- 70
+  n_rare_class <- 30
+
+  group_table <- tibble(
+    group = 1:100,
+    outcome = sample(c(rep(0, n_common_class), rep(1, n_rare_class)))
+  )
+  observation_table <- tibble(
+    group = sample(1:100, 5e4, replace = TRUE),
+    observation = 1:5e4
+  )
+  sample_data <- dplyr::full_join(
+    group_table,
+    observation_table,
+    by = "group",
+    multiple = "all"
+  )
+  rs4 <- group_bootstraps(sample_data, group, times = 5, strata = outcome)
+  sizes4 <- dim_rset(rs4)
+  expect_snapshot(sizes4)
+
+  rate <- purrr::map_dbl(
+    rs4$splits,
+    function(x) {
+      dat <- as.data.frame(x)$outcome
+      mean(dat == "1")
+    }
+  )
+  expect_equal(mean(rate), 0.3, tolerance = 1e-2)
+
+  good_holdout <- purrr::map_lgl(
+    rs4$splits,
+    function(x) {
+      length(intersect(x$in_ind, x$out_id)) == 0
+    }
+  )
+  expect_true(all(good_holdout))
+
+})
+
 
 test_that("bad args", {
-  expect_error(bootstraps(warpbreaks, strata = warpbreaks$tension))
-  expect_error(bootstraps(warpbreaks, strata = c("tension", "wool")))
+  expect_snapshot(error = TRUE, {
+    bootstraps(warpbreaks, strata = warpbreaks$tension)
+  })
+  expect_snapshot(error = TRUE, {
+    bootstraps(warpbreaks, strata = c("tension", "wool"))
+  })
   set.seed(1)
   expect_snapshot(
-    group_bootstraps(warpbreaks, tension),
-    error = TRUE
+    group_bootstraps(warpbreaks, tension)
+  )
+  expect_snapshot(
+    bootstraps(mtcars[2, ])
   )
 })
 
@@ -124,7 +173,8 @@ test_that("printing", {
 
 test_that("rsplit labels", {
   rs <- bootstraps(warpbreaks)
-  all_labs <- purrr::map_df(rs$splits, labels)
+  all_labs <- purrr::map(rs$splits, labels) %>%
+    list_rbind()
   original_id <- rs[, grepl("^id", names(rs))]
   expect_equal(all_labs, original_id)
 })
