@@ -72,8 +72,18 @@ test_that("strata", {
 
 
 test_that("bad args", {
-  expect_error(mc_cv(warpbreaks, strata = warpbreaks$tension))
-  expect_error(mc_cv(warpbreaks, strata = c("tension", "wool")))
+  expect_snapshot(error = TRUE, {
+    mc_cv(mtcars, prop = -1)
+  })
+  expect_snapshot(error = TRUE, {
+    mc_cv(mtcars, prop = 1)
+  })
+  expect_snapshot(error = TRUE, {
+    mc_cv(warpbreaks, strata = warpbreaks$tension)
+  })
+  expect_snapshot(error = TRUE, {
+    mc_cv(warpbreaks, strata = c("tension", "wool"))
+  })
 })
 
 
@@ -84,22 +94,35 @@ test_that("printing", {
 
 test_that("rsplit labels", {
   rs <- mc_cv(mtcars)
-  all_labs <- purrr::map_df(rs$splits, labels)
+  all_labs <- purrr::map(rs$splits, labels) %>%
+    list_rbind()
   original_id <- rs[, grepl("^id", names(rs))]
   expect_equal(all_labs, original_id)
 })
 
 test_that("grouping - bad args", {
-  expect_error(group_mc_cv(warpbreaks, group = warpbreaks$tension))
-  expect_error(group_mc_cv(warpbreaks, group = c("tension", "wool")))
-  expect_error(group_mc_cv(warpbreaks, group = "tensio"))
-  expect_error(group_mc_cv(warpbreaks))
-  expect_error(group_mc_cv(warpbreaks, group = "tension", balance = "groups"))
+  expect_snapshot(error = TRUE, {
+    group_mc_cv(warpbreaks, group = warpbreaks$tension)
+  })
+  expect_snapshot(error = TRUE, {
+    group_mc_cv(warpbreaks, group = c("tension", "wool"))
+  })
+  expect_snapshot(error = TRUE, {
+    group_mc_cv(warpbreaks, group = "tensio")
+  })
+  expect_snapshot(error = TRUE, {
+    group_mc_cv(warpbreaks)
+  })
+  expect_snapshot(error = TRUE, {
+    group_mc_cv(mtcars, group = "cyl", prop = 1)
+  })
+  expect_snapshot(error = TRUE, {
+    group_mc_cv(warpbreaks, group = "tension", balance = "groups")
+  })
   set.seed(1)
-  expect_snapshot(
-    group_mc_cv(warpbreaks, group = "tension", prop = 0.99),
-    error = TRUE
-  )
+  expect_snapshot(error = TRUE, {
+    group_mc_cv(warpbreaks, group = "tension", prop = 0.99)    
+  })
 })
 
 test_that("grouping - default param", {
@@ -125,6 +148,49 @@ test_that("grouping - default param", {
 
 })
 
+test_that("grouping -- strata", {
+  set.seed(11)
+
+  n_common_class <- 70
+  n_rare_class <- 30
+
+  group_table <- tibble(
+    group = 1:100,
+    outcome = sample(c(rep(0, n_common_class), rep(1, n_rare_class)))
+  )
+  observation_table <- tibble(
+    group = sample(1:100, 5e4, replace = TRUE),
+    observation = 1:5e4
+  )
+  sample_data <- dplyr::full_join(
+    group_table,
+    observation_table,
+    by = "group",
+    multiple = "all"
+  )
+  rs4 <- group_mc_cv(sample_data, group, times = 5, strata = outcome)
+  sizes4 <- dim_rset(rs4)
+  expect_snapshot(sizes4)
+
+  rate <- purrr::map_dbl(
+    rs4$splits,
+    function(x) {
+      dat <- as.data.frame(x)$outcome
+      mean(dat == "1")
+    }
+  )
+  expect_equal(mean(rate), 0.3, tolerance = 1e-2)
+
+  good_holdout <- purrr::map_lgl(
+    rs4$splits,
+    function(x) {
+      length(intersect(x$in_ind, x$out_id)) == 0
+    }
+  )
+  expect_true(all(good_holdout))
+
+})
+
 test_that("grouping - tibble input", {
   warpbreaks2 <- tibble::as_tibble(warpbreaks)
   set.seed(11)
@@ -184,7 +250,8 @@ test_that("grouping - printing with ...", {
 
 test_that("grouping - rsplit labels", {
   rs <- group_mc_cv(warpbreaks, "tension")
-  all_labs <- purrr::map_df(rs$splits, labels)
+  all_labs <- purrr::map(rs$splits, labels) %>%
+    list_rbind()
   original_id <- rs[, grepl("^id", names(rs))]
   expect_equal(all_labs, original_id)
 })
